;; Generated package description from web-mode.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "web-mode" "17.3.23.0.20260331.144101" "major mode for editing web templates" '((emacs "24.3.1")) :commit "e93b3fb89fd6345a5ff59795bed712abd486200a" :maintainer '("François-Xavier Bois" . "fxbois@gmail.com") :keywords '("languages") :url "https://web-mode.org")
